## Description
<!-- Describe your changes in detail -->


## Related Issue
<!-- This project only accepts pull requests related to open issues -->
<!-- If suggesting a new feature or change, please discuss it in an issue first -->
<!-- If fixing a bug, there should be an issue describing it with steps to reproduce -->
<!-- If addressing multiple issues, comment on their relation if needed -->
<!-- Please link issues according to the automation rules: -->
<!-- https://docs.gitlab.com/ee/user/project/issues/managing_issues.html#closing-issues-automatically -->


## How Has This Been Tested?
<!-- Please describe in detail how you tested your changes. -->
<!-- Include details of your testing environment, and the tests you ran to -->
<!-- see how your change affects other areas of the code, etc. -->
- [ ] Pytest (python unit test)
- [ ] Mocha (js unit test)
- [ ] Playwright (js e2e test)

### Screenshots (if appropriate):
<!-- Add one or more screenshot that can help to understand, otherwise uncomment the following line: -->
<!-- None -->


## Types of changes
<!-- What types of changes does your code introduce? Put an `x` in all the boxes that apply: -->
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to change)
- [ ] Documentation fix/update

## Which subsystems are modified
<!-- Specify which of the following units are affected by this MR: -->
- [ ] Backend
- [ ] Frontend
- [ ] Other (specify in the summary)

## Checklist:
<!-- Go over all the following points, and put an `x` in all the boxes that apply. -->
<!-- If you're unsure about any of these, don't hesitate to ask. We're here to help! -->
- [ ] My change requires a change to the documentation.
- [ ] I have updated the documentation accordingly.
- [ ] I have added tests to cover my changes.
- [ ] All new and existing tests passed.

<!-- Chose the appropriate labels -->
<!-- /label ~"Task::Analyze"
/label ~"Task::Documentation"
/label ~"Task::Maintenance"
/label ~"Task::Test"
/label ~"no-changelog-needed" -->
/label ~"DPPS::SubSystem::QualPipe"
